% Auto-generated chapter 45 for tirmidhi
% Hadiths in this chapter: 52

\hadithdefcmd{tirmidhi}{2875}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ عَلَى أُبَىِّ بْنِ كَعْبٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أُبَىُّ ‏"‏ ‏.‏ وَهُوَ يُصَلِّي فَالْتَفَتَ أُبَىٌّ وَلَمْ يُجِبْهُ وَصَلَّى أُبَىٌّ فَخَفَّفَ ثُمَّ انْصَرَفَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ السَّلاَمُ عَلَيْكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ السَّلاَمُ مَا مَنَعَكَ يَا أُبَىُّ أَنْ تُجِيبَنِي إِذْ دَعَوْتُكَ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ فِي الصَّلاَةِ ‏.‏ قَالَ ‏"‏ أَفَلَمْ تَجِدْ فِيمَا أَوْحَى اللَّهُ إِلَىَّ أَنِ ‏(‏استَجِيبُوا لِلَّهِ وَلِلرَّسُولِ إِذَا دَعَاكُمْ لِمَا يُحْيِيكُمْ ‏)‏ ‏"‏ ‏.‏ قَالَ بَلَى وَلاَ أَعُودُ إِنْ شَاءَ اللَّهُ ‏.‏ قَالَ ‏"‏ تُحِبُّ أَنْ أُعَلِّمَكَ سُورَةً لَمْ يَنْزِلْ فِي التَّوْرَاةِ وَلاَ فِي الإِنْجِيلِ وَلاَ فِي الزَّبُورِ وَلاَ فِي الْفُرْقَانِ مِثْلُهَا ‏"‏ ‏.‏ قَالَ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ تَقْرَأُ فِي الصَّلاَةِ ‏"‏ ‏.‏ قَالَ فَقَرَأَ أُمَّ الْقُرْآنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ مَا أُنْزِلَتْ فِي التَّوْرَاةِ وَلاَ فِي الإِنْجِيلِ وَلاَ فِي الزَّبُورِ وَلاَ فِي الْفُرْقَانِ مِثْلُهَا وَإِنَّهَا سَبْعٌ مِنَ الْمَثَانِي وَالْقُرْآنُ الْعَظِيمُ الَّذِي أُعْطِيتُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ وَفِيهِ عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى ‏.‏\hadithno{2875}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) came out to Ubayy bin Ka'b, and the Messenger of Allah (ﷺ) said: "O Ubayy!" And he was performing Salat, so Ubayy turned around but he did not respond to him, so Ubayy finished his Salat quickly. Then he turned to the Messenger of Allah (ﷺ) and said: 'As-Salamu 'Alaikum, O Messenger of Allah!' The Messenger of Allah (ﷺ) said: 'Wa 'Alaikum As-Salam - what prevented you from responding to me when I called you Ubayy?' He said: 'O Messenger of Allah! I was performing Salat.' So he said: 'Do you not find among what Allah revealed to me: Respond to Allah and to the Messenger when they call you to what gives you life?' He said: 'Of course, I shall not repeat that, if Allah wills.' He said: 'Would you like for me to teach you a Surah the likes of which has neither been revealed in the Tawrah, nor the Injil, nor the Zabur, nor in the entire Qur'an?' He said: "Yes, O Messenger of Allah!' The Messenger of Allah (ﷺ) said: 'What do you recite in your Salat?' He said: 'I recite Umm Al-Qur'an.' So the Messenger of Allah (ﷺ) said: 'By the One in Whose Hand is my soul! The like of it has neither been revealed in the Tawrah, nor the Injil nor the Zabur, nor in the Furqan. It is the seven oft-repeated, and the Magnificent Qur'an which I was given}}
\hadithdefcmd{tirmidhi}{2876}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ الْحُلْوَانِيُّ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَطَاءٍ، مَوْلَى أَبِي أَحْمَدَ عَنْ أَبِي هُرَيْرَةَ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْثًا وَهُمْ ذُو عَدَدٍ فَاسْتَقْرَأَهُمْ فَاسْتَقْرَأَ كُلَّ رَجُلٍ مِنْهُمْ مَا مَعَهُ مِنَ الْقُرْآنِ فَأَتَى عَلَى رَجُلٍ مِنْهُمْ مِنْ أَحْدَثِهِمْ سِنًّا فَقَالَ ‏"‏ مَا مَعَكَ يَا فُلاَنُ ‏"‏ ‏.‏ قَالَ مَعِي كَذَا وَكَذَا وَسُورَةُ الْبَقَرَةِ ‏.‏ قَالَ ‏"‏ أَمَعَكَ سُورَةُ الْبَقَرَةِ ‏"‏ ‏.‏ فَقَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاذْهَبْ فَأَنْتَ أَمِيرُهُمْ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنْ أَشْرَافِهِمْ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا مَنَعَنِي أَنْ أَتَعَلَّمَ سُورَةَ الْبَقَرَةِ إِلاَّ خَشْيَةَ أَلاَّ أَقُومَ بِهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَعَلَّمُوا الْقُرْآنَ فَاقْرَءُوهُ وَأَقْرِئُوهُ فَإِنَّ مَثَلَ الْقُرْآنِ لِمَنْ تَعَلَّمَهُ فَقَرَأَهُ وَقَامَ بِهِ كَمَثَلِ جِرَابٍ مَحْشُوٍّ مِسْكًا يَفُوحُ بِرِيحِهِ كُلُّ مَكَانٍ وَمَثَلُ مَنْ تَعَلَّمَهُ فَيَرْقُدُ وَهُوَ فِي جَوْفِهِ كَمَثَلِ جِرَابٍ وُكِئَ عَلَى مِسْكٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ اللَّيْثُ بْنُ سَعْدٍ عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَطَاءٍ، مَوْلَى أَبِي أَحْمَدَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ حَدَّثَنَا قُتَيْبَةُ عَنِ اللَّيْثِ فَذَكَرَهُ ‏.‏\hadithno{2876}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:"The Messenger of Allah (ﷺ) sent an expedition force [comprised] of many, and he asked each what he could recite, so each one of them mentioned what he could recite - meaning what he had memorized of the Qur'an. He came to one of the youngest men among them and said: 'What have you memorized O so-and-so?' He said: 'I memorized this and that and Surat Al-Baqarah.' He said: 'You memorized Surat Al-Baqarah?' He said: "Yes.' He said: "Then go, for you are their commander.' A man among their chief said: 'By Allah [O Messenger of Allah]! Nothing prevented me from learning Surat Al-Baqarah except fearing that I would not be able to stand with (in voluntary night prayer).' The Messenger of Allah (ﷺ) said: 'Learn the Qur'an to recite it, for indeed the parable of the Qur'an for the one who recites it and stands with it (in prayer) is that of a bag full of musk whose scent fills the air all around. And the parable of the one who learns it then sleeps while it is in his memory is that of a bag containing musk that is tied shut}}
\hadithdefcmd{tirmidhi}{2877}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَجْعَلُوا بُيُوتَكُمْ مَقَابِرَ وَإِنَّ الْبَيْتَ الَّذِي تُقْرَأُ فِيهِ الْبَقَرَةُ لاَ يَدْخُلُهُ الشَّيْطَانُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2877}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Do not turn your houses into graves. Indeed Ash-Shaitan does not enter the house in which Surat Al-Baqarah is recited}}
\hadithdefcmd{tirmidhi}{2878}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ حَكِيمِ بْنِ جُبَيْرٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِكُلِّ شَيْءٍ سَنَامٌ وَإِنَّ سَنَامَ الْقُرْآنِ سُورَةُ الْبَقَرَةِ وَفِيهَا آيَةٌ هِيَ سَيِّدَةُ آىِ الْقُرْآنِ هِيَ آيَةُ الْكُرْسِيِّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حَكِيمِ بْنِ جُبَيْرٍ ‏.‏ وَقَدْ تَكَلَّمَ شُعْبَةُ فِي حَكِيمِ بْنِ جُبَيْرٍ وَضَعَّفَهُ ‏.‏\hadithno{2878}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ): "For everything there is a hump (pinnacle) and the hump (pinnacle) of the Qur'an is Surat Al-Baqarah, in it there is an Ayah which is the master of the Ayat in the Qur'an; [it is] Ayat Al-Kursi}}
\hadithdefcmd{tirmidhi}{2879}{حَدَّثَنَا يَحْيَى بْنُ الْمُغِيرَةِ أَبُو سَلَمَةَ الْمَخْزُومِيُّ الْمَدَنِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الْمُلَيْكِيِّ، عَنْ زُرَارَةَ بْنِ مُصْعَبٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قَرَأَ حم الْمُؤْمِنَ إِلَى ‏:‏ ‏(‏إِلَيْهِ الْمَصِيرُ ‏)‏ وَآيَةَ الْكُرْسِيِّ حِينَ يُصْبِحُ حُفِظَ بِهِمَا حَتَّى يُمْسِيَ وَمَنْ قَرَأَهُمَا حِينَ يُمْسِيَ حُفِظَ بِهِمَا حَتَّى يُصْبِحَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرِ بْنِ أَبِي مُلَيْكَةَ الْمُلَيْكِيِّ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَزُرَارَةُ بْنُ مُصْعَبٍ هُوَ ابْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَهُوَ جَدُّ أَبِي مُصْعَبٍ الْمَدَنِيِّ ‏.‏\hadithno{2879}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whoever recites Ha Mim Al-Mu'min - up to - To Him is the return (40:1-3) and Ayat Al-Kursi when he reaches (gets up in) the morning, he will be protected by them until the evening. And whoever recites them when he reaches the evening, he will be protected by them until the morning}}
\hadithdefcmd{tirmidhi}{2880}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أَخِيهِ، عِيسَى عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، أَنَّهُ كَانَتْ لَهُ سَهْوَةٌ فِيهَا تَمْرٌ فَكَانَتْ تَجِيءُ الْغُولُ فَتَأْخُذُ مِنْهُ قَالَ فَشَكَا ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ فَاذْهَبْ فَإِذَا رَأَيْتَهَا فَقُلْ بِسْمِ اللَّهِ أَجِيبِي رَسُولَ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏ قَالَ فَأَخَذَهَا فَحَلَفَتْ أَنْ لاَ تَعُودَ فَأَرْسَلَهَا فَجَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا فَعَلَ أَسِيرُكَ ‏"‏ ‏.‏ قَالَ حَلَفَتْ أَنْ لاَ تَعُودَ فَقَالَ ‏"‏ كَذَبَتْ وَهِيَ مُعَاوِدَةٌ لِلْكَذِبِ ‏"‏ ‏.‏ قَالَ فَأَخَذَهَا مَرَّةً أُخْرَى فَحَلَفَتْ أَنْ لاَ تَعُودَ فَأَرْسَلَهَا فَجَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا فَعَلَ أَسِيرُكَ ‏"‏ ‏.‏ قَالَ حَلَفَتْ أَنْ لاَ تَعُودَ ‏.‏ فَقَالَ ‏"‏ كَذَبَتْ وَهِيَ مُعَاوِدَةٌ لِلْكَذِبِ ‏"‏ ‏.‏ فَأَخَذَهَا فَقَالَ مَا أَنَا بِتَارِكِكِ حَتَّى أَذْهَبَ بِكِ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَقَالَتْ إِنِّي ذَاكِرَةٌ لَكَ شَيْئًا آيَةَ الْكُرْسِيِّ اقْرَأْهَا فِي بَيْتِكَ فَلاَ يَقْرَبُكَ شَيْطَانٌ وَلاَ غَيْرُهُ ‏.‏ قَالَ فَجَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا فَعَلَ أَسِيرُكَ ‏"‏ ‏.‏ قَالَ فَأَخْبَرَهُ بِمَا قَالَتْ ‏.‏ قَالَ ‏"‏ صَدَقَتْ وَهِيَ كَذُوبٌ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ أُبَىِّ بْنِ كَعْبٍ ‏.‏\hadithno{2880}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdur-Rahman bin Abi Laila:that Abu Ayyub Al-Ansari had a store house in which he kept dates. A ghoul would come and take from it, so he complained about that to the Prophet (ﷺ). So he said: "Go, and when you see her say: 'In the Name of Allah, answer to the Messenger of Allah (ﷺ).'" He said: "So I caught her, and she swore that she would not return, so I released her." He went to the Prophet (ﷺ) and he said: "What did your captive do?" He said: "She swore not to return." He said: "She has lied, and she will come again to lie." He said: "I caught her another time and she swore that she would not return, so I released her, and went to the Prophet (ﷺ)." He said: "What did your captive do?" He said: "She swore that she would not return." So he said: "She lied and she will come again to lie." So he caught her and said: "I shall not let you go until you accompany me to the Prophet (ﷺ)." She said: "I shall tell you something: If you recite Ayat Al-Kursi in your home, then no Shaitan, nor any other shall come near you." So he went to the Prophet (ﷺ) and he said: "What did your captive do?" He said: "I informed him of what she said, and he said: 'She told the truth and she is a continuous liar}}
\hadithdefcmd{tirmidhi}{2881}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ مَنْصُورِ بْنِ الْمُعْتَمِرِ، عَنْ إِبْرَاهِيمَ بنِ يَزِيدَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ الآيَتَيْنِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي لَيْلَةٍ كَفَتَاهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2881}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Mas'ud Al-Ansari:that the Messenger of Allah (ﷺ) said: "Whoever recites the last two Ayat of Surat Al-Baqarah during the night, they shall suffice him}}
\hadithdefcmd{tirmidhi}{2882}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَشْعَثَ بْنِ عَبْدِ الرَّحْمَنِ الْجَرْمِيِّ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ الْجَرْمِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ كَتَبَ كِتَابًا قَبْلَ أَنْ يَخْلُقَ السَّمَاوَاتِ وَالأَرْضَ بِأَلْفَىْ عَامٍ أَنْزَلَ مِنْهُ آيَتَيْنِ خَتَمَ بِهِمَا سُورَةَ الْبَقَرَةِ وَلاَ يُقْرَآنِ فِي دَارٍ ثَلاَثَ لَيَالٍ فَيَقْرَبُهَا شَيْطَانٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2882}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated An-Nu'man bin Bashir:that the Prophet (ﷺ) said: "Indeed Allah wrote in a book two thousand years before He created the heavens and the earth, and He sent down two Ayat from it to end Surat Al-Baqarah with. If they are recited for three nights in a home, no Shaitan shall come near it}}
\hadithdefcmd{tirmidhi}{2883}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ أَخْبَرَنَا هِشَامُ بْنُ إِسْمَاعِيلَ أَبُو عَبْدِ الْمَلِكِ الْعَطَّارِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سُلَيْمَانَ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ حَدَّثَهُمْ عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ نَوَّاسِ بْنِ سَمْعَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يَأْتِي الْقُرْآنُ وَأَهْلُهُ الَّذِينَ يَعْمَلُونَ بِهِ فِي الدُّنْيَا تَقْدُمُهُ سُورَةُ الْبَقَرَةِ وَآلُ عِمْرَانَ ‏"‏ ‏.‏ قَالَ نَوَّاسٌ وَضَرَبَ لَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَةَ أَمْثَالٍ مَا نَسِيتُهُنَّ بَعْدُ قَالَ ‏"‏ تَأْتِيَانِ كَأَنَّهُمَا غَيَابَتَانِ وَبَيْنَهُمَا شَرْقٌ أَوْ كَأَنَّهُمَا غَمَامَتَانِ سَوْدَاوَانِ أَوْ كَأَنَّهُمَا ظُلَّةٌ مِنْ طَيْرٍ صَوَافَّ تُجَادِلاَنِ عَنْ صَاحِبِهِمَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ يَجِيءُ ثَوَابُ قِرَاءَتِهِ كَذَا فَسَّرَ بَعْضُ أَهْلِ الْعِلْمِ هَذَا الْحَدِيثَ وَمَا يُشْبِهُ هَذَا مِنَ الأَحَادِيثِ أَنَّهُ يَجِيءُ ثَوَابُ قِرَاءَةِ الْقُرْآنِ ‏.‏ وَفِي حَدِيثِ النَّوَّاسِ عَنِ النَّبِيِّ صلى الله عليه وسلم مَا يَدُلُّ عَلَى مَا فَسَّرُوا إِذْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَأَهْلُهُ الَّذِينَ يَعْمَلُونَ بِهِ فِي الدُّنْيَا ‏"‏ ‏.‏ فَفِي هَذَا دَلاَلَةٌ أَنَّهُ يَجِيءُ ثَوَابُ الْعَمَلِ ‏.‏\hadithno{2883}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated An-Nawwas bin Sam'an:that the Prophet (ﷺ) said: "The Qur'an shall come, and its people who acted according to it in the world. Surat Al-Baqarah and Al 'Imran shall be in front of it. An-Nawwas said: "The Messenger of Allah (ﷺ) stated three parables about them which I have not since forgotten, he said: "They will come as if they are two shades between which there is illumination, or as if they are two shady clouds, or as if they are shadows of lines of birds arguing on behalf of their people}}
\hadithdefcmd{tirmidhi}{2884}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا الْحُمَيْدِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، فِي تَفْسِيرِ حَدِيثِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ قَالَ مَا خَلَقَ اللَّهُ مِنْ سَمَاءٍ وَلاَ أَرْضٍ أَعْظَمَ مِنْ آيَةِ الْكُرْسِيِّ ‏.‏ قَالَ سُفْيَانُ لأَنَّ آيَةَ الْكُرْسِيِّ هُوَ كَلاَمُ اللَّهِ وَكَلاَمُ اللَّهِ أَعْظَمُ مِنْ خَلْقِ اللَّهِ مِنَ السَّمَاءِ وَالأَرْضِ ‏.‏\hadithno{2884}\hadithgrade{Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdullah bin Mas'ud:"Allah has not created in the heavens nor in the earth what is more magnificent than Ayat Al-Kursi." Sufyan said: "Because Ayat Al-Kursi is the Speech of Allah, and Allah's Speech is greater than Allah's creation of the heavens and the earth}}
\hadithdefcmd{tirmidhi}{2885}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ يَقُولُ بَيْنَمَا رَجُلٌ يَقْرَأُ سُورَةَ الْكَهْفِ إِذْ رَأَى دَابَّتَهُ تَرْكُضُ فَنَظَرَ فَإِذَا مِثْلُ الْغَمَامَةِ أَوِ السَّحَابَةِ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تِلْكَ السَّكِينَةُ نَزَلَتْ مَعَ الْقُرْآنِ أَوْ نَزَلَتْ عَلَى الْقُرْآنِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أُسَيْدِ بْنِ حُضَيْرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2885}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Ishaq:hearing Al-Bara say: "There was a man reciting [Surat] Al-Kahf when he saw his riding animal stamping his feet, so he looked and there was something like a shadow or cloud, so he went to the Messenger of Allah (ﷺ) and mentioned that to him. The Prophet (ﷺ) said: "That was the tranquility which descends with the Qur'an, or descends because of the Qur'an}}
\hadithdefcmd{tirmidhi}{2886}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَرَأَ ثَلاَثَ آيَاتٍ مِنْ أَوَّلِ الْكَهْفِ عُصِمَ مِنْ فِتْنَةِ الدَّجَّالِ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2886}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Ad-Darda:that the Prophet (ﷺ) said: "Whoever recites three Ayat from the beginning of Al-Kahf he is protected from the turmoil of the Dajjal}}
\hadithdefcmd{tirmidhi}{2887}{حَدَّثَنَا قُتَيْبَةُ وَسُفْيَانُ بْنُ وَكِيعٍ، قَالاَ حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ الرُّؤَاسِيُّ، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ هَارُونَ أَبِي مُحَمَّدٍ، عَنْ مُقَاتِلِ بْنِ حَيَّانَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ لِكُلِّ شَيْءٍ قَلْبًا وَقَلْبُ الْقُرْآنِ يس وَمَنْ قَرَأَ يس كَتَبَ اللَّهُ لَهُ بِقِرَاءَتِهَا قِرَاءَةَ الْقُرْآنِ عَشْرَ مَرَّاتٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ وَبِالْبَصْرَةِ لاَ يَعْرِفُونَ مِنْ حَدِيثِ قَتَادَةَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَهَارُونُ أَبُو مُحَمَّدٍ شَيْخٌ مَجْهُولٌ ‏.‏ حَدَّثَنَا أَبُو مُوسَى مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، قَالَ حَدَّثَنَا قُتَيْبَةُ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، بِهَذَا ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، وَلاَ يَصِحُّ مِنْ قِبَلِ إِسْنَادِهِ إِسْنَادُهُ ضَعِيفٌ ‏.‏ وَ فِي البَابِ عَنْ أَبِي هُرَيرَةَ\hadithno{2887}\hadithgrade{Al-Albani: Mawdu; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas:that the Messenger of Allah (ﷺ) said: "Indeed for everything there is a heart, and the Qur'an's heart is Ya Sin. Whoever recites Ya Sin, then for its recitation, Allah writes for him that he recited the Qur'an ten times}}
\hadithdefcmd{tirmidhi}{2888}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، قَالَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ عُمَرَ بْنِ أَبِي خَثْعَمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ حم الدُّخَانَ فِي لَيْلَةٍ أَصْبَحَ يَسْتَغْفِرُ لَهُ سَبْعُونَ أَلْفَ مَلَكٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَعُمَرُ بْنُ أَبِي خَثْعَمٍ يُضَعَّفُ ‏.‏ قَالَ مُحَمَّدٌ وَهُوَ مُنْكَرُ الْحَدِيثِ ‏.‏\hadithno{2888}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whoever recites Ha Mim Ad-Dukhan during the night, in the morning seventy thousand angels seek forgiveness for him}}
\hadithdefcmd{tirmidhi}{2889}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، قَالَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ هِشَامٍ أَبِي الْمِقْدَامِ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ حم الدُّخَانَ فِي لَيْلَةِ الْجُمُعَةِ غُفِرَ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَهِشَامٌ أَبُو الْمِقْدَامِ يُضَعَّفُ وَلَمْ يَسْمَعِ الْحَسَنُ مِنْ أَبِي هُرَيْرَةَ هَكَذَا قَالَ أَيُّوبُ وَيُونُسُ بْنُ عُبَيْدٍ وَعَلِيُّ بْنُ زَيْدٍ ‏.‏\hadithno{2889}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whoever recites Ha Mum Ad-Dukhan during Friday night, he shall be forgiven}}
\hadithdefcmd{tirmidhi}{2890}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ عَمْرِو بْنِ مَالِكٍ النُّكْرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي الْجَوْزَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ضَرَبَ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم خِبَاءَهُ عَلَى قَبْرٍ وَهُوَ لاَ يَحْسِبُ أَنَّهُ قَبْرٌ فَإِذَا فِيهِ إِنْسَانٌ يَقْرَأُ سُورَةَ تَبَارَكَ الَّذِي بِيَدِهِ الْمُلْكُ حَتَّى خَتَمَهَا فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي ضَرَبْتُ خِبَائِي عَلَى قَبْرٍ وَأَنَا لاَ أَحْسِبُ أَنَّهُ قَبْرٌ فَإِذَا فِيهِ إِنْسَانٌ يَقْرَأُ سُورَةَ تَبَارَكَ الْمُلْكُ حَتَّى خَتَمَهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هِيَ الْمَانِعَةُ هِيَ الْمُنْجِيَةُ تُنْجِيهِ مِنْ عَذَابِ الْقَبْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2890}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:"One of the companions of the Prophet (ﷺ) pitched a tent on a grave without knowing that it was a grave. Suddenly he heard a person from the grave reciting Surah al-Mulk till he completed it. So he went to the Prophet (ﷺ) and said: 'Oh Messenger of Allah, I pitched my tent on a grave without realizing that is was a grave. Then suddenly I heard a person from the grave reciting Surah al-Mulk till he completed it.' The Messenger of Allah (ﷺ) said: 'It is the defender, it is the deliverer - it delivers from the punishment of the grave}}
\hadithdefcmd{tirmidhi}{2891}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عَبَّاسٍ الْجُشَمِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ سُورَةً مِنَ الْقُرْآنِ ثَلاَثُونَ آيَةً شَفَعَتْ لِرَجُلٍ حَتَّى غُفِرَ لَهُ وَهِيَ سُورَةُ تَبَارَكَ الَّذِي بِيَدِهِ الْمُلْكُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2891}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) said: "Indeed there is a Surah in the Qur'an of thirty Ayat, which intercedes for a man until he is forgiven. It is [Surah] Tabarak Alladhi Biyadihil-Mulk}}
\hadithdefcmd{tirmidhi}{2892}{حَدَّثَنَا هُرَيْمُ بْنُ مِسْعَرٍ، - تِرْمِذِيٌّ - قَالَ حَدَّثَنَا الْفُضَيْلُ بْنُ عِيَاضٍ، عَنْ لَيْثٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَنَامُ حَتَّى يَقْرَأَ ‏:‏ ‏(‏الم * تَنْزِيلُ ‏)‏ وَ ‏(‏ تَبَارَكَ الَّذِي بِيَدِهِ الْمُلْكُ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ لَيْثِ بْنِ أَبِي سُلَيْمٍ مِثْلَ هَذَا ‏.‏ وَرَوَاهُ مُغِيرَةُ بْنُ مُسْلِمٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏ وَرَوَى زُهَيْرٌ قَالَ قُلْتُ لأَبِي الزُّبَيْرِ سَمِعْتَ مِنْ جَابِرٍ يَذْكُرُ هَذَا الْحَدِيثَ ‏.‏ فَقَالَ أَبُو الزُّبَيْرِ إِنَّمَا أَخْبَرَنِيهِ صَفْوَانُ أَوِ ابْنُ صَفْوَانَ وَكَأَنَّ زُهَيْرًا أَنْكَرَ أَنْ يَكُونَ هَذَا الْحَدِيثَ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ لَيْثٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ حَدَّثَنَا هُرَيْمٌ بن مِسْعَرٍ، قَالَ حَدَّثَنَا فُضَيْلٌ، عَنْ لَيْثٍ، عَنْ طَاوُسٍ، قَالَ تَفْضُلاَنِ عَلَى كُلِّ سُورَةٍ مِنَ الْقُرْآنِ بِسَبْعِينَ حَسَنَةً ‏.‏\hadithno{2892}\hadithgrade{Al-Albani: Daif Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) would not sleep until he recited Alif Lam Mim Tanzil and: Tabarak Alladhi Biyadihil-Mulk." This Hadith was reported similarly by more than one from Laith bin Abi Sulaim. Mughirah bin Muslim reported it from Abu Az-Zubair, from Jabir from the Prophet (ﷺ) and it is similar to this. Zuhair reported it and said: "I said to Abu Az-Zubair: 'Did you hear Jabir mentioning this Hadith?' He said: 'Safwan or Ibn Safwan informed me of it.'" It is as if Zuhair rejected the idea that this Hadith was from Abu Az-Zubair from Jabir. (Another chain) with similar in meaning. (Another chain) that Tawus said: "They are seventy good merits more of virtue in it than every Surah in the Qur'an}}
\hadithdefcmd{tirmidhi}{2893}{(حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْحَرَشِيُّ الْبَصْرِيُّ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ سَلْمِ بْنِ صَالِحٍ الْعِجْلِيُّ، قَالَ حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ إِذَا زُلْزِلَتِ عُدِلَتْ لَهُ بِنِصْفِ الْقُرْآنِ وَمَنْ قَرَأَْ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏)‏ عُدِلَتْ لَهُ بِرُبْعِ الْقُرْآنِ وَمَنْ قَرَأَْ قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ عُدِلَتْ لَهُ بِثُلُثِ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ هَذَا الشَّيْخِ الْحَسَنِ بْنِ سَلْمٍ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{2893}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "Whoever recites Idha Zulzilat, it equals half of the Qur'an for him. Whoever recites: Qul Ya Ayyuhal-Kafirun it equals a fourth of the Qur'an for him. And whoever recites: Qul Huwa Allahu Ahad it equals a third of the Qur'an for him}}
\hadithdefcmd{tirmidhi}{2894}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَخْبَرَنَا يَمَانُ بْنُ الْمُغِيرَةِ الْعَنَزِيُّ، حَدَّثَنَا عَطَاءٌ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا زُلْزِلَتِ تَعْدِلُ نِصْفَ الْقُرْآنِ وَقُلْ هُوَ اللَّهُ أَحَدٌ تَعْدِلُ ثُلُثَ الْقُرْآنِ وَ قُلْْ يَا أَيُّهَا الْكَافِرُونَ تَعْدِلُ رُبُعَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَمَانِ بْنِ الْمُغِيرَةِ ‏.‏\hadithno{2894}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said: "Idha Zulzilat is equal to half of the Qur'an, Qul Huwa Allahu Ahad is equal to a third of the Qur'an, and Yul Ya Ayyuhal-Kafirun is equal to a fourth of the Qur'an}}
\hadithdefcmd{tirmidhi}{2895}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ الْبَصْرِيُّ، قَالَ حَدَّثَنِي ابْنُ أَبِي فُدَيْكٍ، قَالَ أَخْبَرَنَا سَلَمَةُ بْنُ وَرْدَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِرَجُلٍ مِنْ أَصْحَابِهِ ‏"‏ هَلْ تَزَوَّجْتَ يَا فُلاَنُ ‏"‏ ‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ وَلاَ عِنْدِي مَا أَتَزَوَّجُ بِهِ ‏.‏ قَالَ ‏"‏ أَلَيْسَ مَعَكَ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ ثُلُثُ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ ‏"‏ أَلَيْسَ مَعَكَ ‏(‏ إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ ‏)‏ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ رُبُعُ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ ‏"‏ أَلَيْسَ مَعَكَ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏"‏ ‏.‏ قَالَ بَلَى قَالَ ‏"‏ رُبُعُ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ ‏"‏ أَلَيْسَ مَعَكَ ‏(‏إِذَا زُلْزِلَتِ الأَرْضُ ‏)‏ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ رُبُعُ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ ‏"‏ تَزَوَّجْ تَزَوَّجْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2895}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said to a man among his Companions: "Have you married O so-and-so?" He said: "No by Allah O Messenger of Allah! And I do not have anything to marry with." He said: "Do you not know: Qul Huwa Allahu Ahad?" He said: "Of course." He said: "It is a third of the Qur'an." He said: "Do you not know Idha Ja Nasrullahi Wal-Fath?" He said: "Of course." He said: "It is a fourth of the Qur'an." He said: "Do you not know Qul Ya Ayyuhal-Kafirun?" He said: "Of course." He said: "It is a fourth of the Qur'an." He said: "Do you not know Idha Zulzilat Al-Ard?" He said: "Of course." He said: "It is a fourth of the Qur'an." He said: "Marry, marry}}
\hadithdefcmd{tirmidhi}{2896}{حَدَّثَنَا قُتَيْبَةُ وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ رَبِيعِ بْنِ خُثَيْمٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ امْرَأَةٍ، وَهِيَ امْرَأَةُ أَبِي أَيُّوبَ عَنْ أَبِي أَيُّوبَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيَعْجَزُ أَحَدُكُمْ أَنْ يَقْرَأَ فِي لَيْلَةٍ ثُلُثَ الْقُرْآنِ مَنْ قَرَأَ اللَّهُ الْوَاحِدُ الصَّمَدُ فَقَدْ قَرَأَ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي الدَّرْدَاءِ وَأَبِي سَعِيدٍ وَقَتَادَةَ بْنِ النُّعْمَانِ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَابْنِ عُمَرَ وَأَبِي مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَلاَ نَعْرِفُ أَحَدًا رَوَى هَذَا الْحَدِيثَ أَحْسَنَ مِنْ رِوَايَةِ زَائِدَةَ وَتَابَعَهُ عَلَى رِوَايَتِهِ إِسْرَائِيلُ وَالْفُضَيْلُ بْنُ عِيَاضٍ وَقَدْ رَوَى شُعْبَةُ وَغَيْرُ وَاحِدٍ مِنَ الثِّقَاتِ هَذَا الْحَدِيثَ عَنْ مَنْصُورٍ وَاضْطَرَبُوا فِيهِ ‏.‏\hadithno{2896}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Ayyub:that the Messenger of Allah (ﷺ) said: "Would one of you like to recite a third of the Qur'an during a night? Whoever recited: Allaahu Al-Wahid As-Samad then he has recited a third of the Qur'an}}
\hadithdefcmd{tirmidhi}{2897}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ حُنَيْنٍ، مَوْلًى لآلِ زَيْدِ بْنِ الْخَطَّابِ أَوْ مَوْلَى زَيْدِ بْنِ الْخَطَّابِ عَنْ أَبِي هُرَيْرَةَ، قَالَ أَقْبَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَمِعَ رَجُلاً يَقْرَأُْ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ * اللَّهُ الصَّمَدُ ‏)‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ قُلْتُ وَمَا وَجَبَتْ قَالَ ‏"‏ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مَالِكِ بْنِ أَنَسٍ وَابْنُ حُنَيْنٍ هُوَ عُبَيْدُ بْنُ حُنَيْنٍ ‏.‏\hadithno{2897}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:"I went out with the Messenger of Allah and heard a man reciting Qul Huwa Allahu Ahad [Allahus-Samad] so the Messenger of Allah (ﷺ) said: 'It is obligatory.' I said: 'What is obligatory?' He said: 'Paradise}}
\hadithdefcmd{tirmidhi}{2898}{حَدَّثَنَا مُحَمَّدُ بْنُ مَرْزُوقٍ الْبَصْرِيُّ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ مَيْمُونٍ أَبُو سَهْلٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قَرَأَ كُلَّ يَوْمٍ مِائَتَىْ مَرَّةٍ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ مُحِيَ عَنْهُ ذُنُوبُ خَمْسِينَ سَنَةً إِلاَّ أَنْ يَكُونَ عَلَيْهِ دَيْنٌ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَرَادَ أَنْ يَنَامَ عَلَى فِرَاشِهِ فَنَامَ عَلَى يَمِينِهِ ثُمَّ قَرَأَْ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ مِئَةَ مَرَّةٍ فَإِذَا كَانَ يَوْمُ الْقِيَامَةِ يَقُولُ لَهُ الرَّبُّ يَا عَبْدِي ادْخُلْ عَلَى يَمِينِكَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ ثَابِتٍ عَنْ أَنَسٍ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ أَيْضًا عَنْ ثَابِتٍ ‏.‏\hadithno{2898}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:that the Prophet (ﷺ) said: "Whoever recited Qul Huwa Allahu Ahad two hundred times everyday, fifty years worth of his sins will be removed - unless he owed a debt." And another narration with this chain, from the Prophet (ﷺ) that he said: "Whoever wants to sleep upon his bed and sleeps on his right side, then he recites Qul Huwa Allahu Ahad one hundred times, then on the Day of Judgement the Lord, Blessed and Most High shall say: 'O My slave! Enter Paradise on your right}}
\hadithdefcmd{tirmidhi}{2899}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ تَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2899}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Qul Huwa Allahu Ahad is equal to a third of the Qur'an}}
\hadithdefcmd{tirmidhi}{2900}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، قَالَ حَدَّثَنَا أَبُو حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْشِدُوا فَإِنِّي سَأَقْرَأُ عَلَيْكُمْ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ فَحَشَدَ مَنْ حَشَدَ ثُمَّ خَرَجَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَقَرَأَْ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ ثُمَّ دَخَلَ فَقَالَ بَعْضُنَا لِبَعْضٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنِّي سَأَقْرَأُ عَلَيْكُمْ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏ إِنِّي لأُرَى هَذَا خَبَرٌ جَاءَهُ مِنَ السَّمَاءِ ثُمَّ خَرَجَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنِّي قُلْتُ سَأَقْرَأُ عَلَيْكُمْ ثُلُثَ الْقُرْآنِ أَلاَ وَإِنَّهَا تَعْدِلُ بثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو حَازِمٍ الأَشْجَعِيُّ اسْمُهُ سَلْمَانُ ‏.‏\hadithno{2900}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Gather and I shall recite to you one third of the Qur'an." He said: "So whoever was to gather did so, then the Messenger of Allah (ﷺ) came out and recited Qul Huwa Allahu Ahad. Then he went back in. Some of them said to each other: "The Messenger of Allah (ﷺ) said: 'I shall recite to you one third of the Qur'an' I thought that this was news from the Heavens." Allah's Prophet (ﷺ) came out and said: "Indeed I said that I would recite to you one third of the Qur'an, and it is indeed equal to one third of the Qur'an}}
\hadithdefcmd{tirmidhi}{2901}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَجُلٌ مِنَ الأَنْصَارِ يَؤُمُّهُمْ فِي مَسْجِدِ قُبَاءَ فَكَانَ كُلَّمَا افْتَتَحَ سُورَةً يَقْرَأُ لَهُمْ فِي الصَّلاَةِ يَقْرَأَ بِهَا افْتَتَحَ بِـ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ حَتَّى يَفْرُغَ مِنْهَا ثُمَّ يَقْرَأُ بِسُورَةٍ مَعَهَا وَكَانَ يَصْنَعُ ذَلِكَ فِي كُلِّ رَكْعَةٍ فَكَلَّمَهُ أَصْحَابُهُ فَقَالُوا إِنَّكَ تَقْرَأُ بِهَذِهِ السُّورَةِ ثُمَّ لاَ تَرَى أَنَّهَا تُجْزِيكَ حَتَّى تَقْرَأَ بِسُورَةٍ أُخْرَى فَإِمَّا أَنْ تَقْرَأَ بِهَا وَإِمَّا أَنْ تَدَعَهَا وَتَقْرَأَ بِسُورَةٍ أُخْرَى ‏.‏ قَالَ مَا أَنَا بِتَارِكِهَا إِنْ أَحْبَبْتُمْ أَنْ أَؤُمَّكُمْ بِهَا فَعَلْتُ وَإِنْ كَرِهْتُمْ تَرَكْتُكُمْ ‏.‏ وَكَانُوا يَرَوْنَهُ أَفْضَلَهُمْ وَكَرِهُوا أَنْ يَؤُمَّهُمْ غَيْرُهُ فَلَمَّا أَتَاهُمُ النَّبِيُّ صلى الله عليه وسلم أَخْبَرُوهُ الْخَبَرَ فَقَالَ ‏"‏ يَا فُلاَنُ مَا يَمْنَعُكَ مِمَّا يَأْمُرُ بِهِ أَصْحَابُكَ وَمَا يَحْمِلُكَ أَنْ تَقْرَأَ هَذِهِ السُّورَةَ فِي كُلِّ رَكْعَةٍ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أُحِبُّهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ حُبَّهَا أَدْخَلَكَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ ثَابِتٍ ‏البُنَانِيُّ وَ قد رَوَى مُبَارَكُ بْنُ فَضَالَةَ عَنْ ثَابِتٍ عَنْ أَنَسٍ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنِّي أُحِبُّ هَذِهِ السُّورَةَْ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ فَقَالَ ‏"‏ إِنَّ حُبَّكَ إِيَّاهَا يُدْخِلُكَ الْجَنَّةَ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ أَبُو دَاوُدَ سُلَيْمَانُ بْنُ الأَشْعَثِ قَالَ حَدَّثَنَا أَبُو الْوَلِيدِ قَالَ حَدَّثَنَا مُبَارَكُ بْنُ فَضَالَةَ بِهَذَا ‏.‏\hadithno{2901}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas bin Malik:"There was a man from the Ansar who led them (in Salat) at Masjid Quba. Every time he was to recite a Surah for them during Salat, he would begin by reciting Qul Huwa Allahu Ahad until he finished, then he would recite another Surah with it. He did that in each Rak'ah. His companions talked to him and said: 'You recite this Surah. You should either recite it or leave it and recite another Surah.'" He said: "I shall not leave it, if you would like me to lead you with it then I shall do so, and if you do not like it then I shall leave you." And they considered him the best among them, and they did not like the idea of someone else leading them. So when the Prophet (ﷺ) came to them they informed him about what had happened and he (ﷺ) said: "O so-and-so! What prevents you from doing what your companions told you to do, why do recite this Surah in every Rak'ah" He said: "O Messenger of Allah! Indeed I love it." So the Messenger of Allah (ﷺ) said: "Your love for it shall have you admitted into Paradise}}
\hadithdefcmd{tirmidhi}{2902}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، قَالَ أَخْبَرَنِي قَيْسُ بْنُ أَبِي حَازِمٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ قَدْ أَنْزَلَ اللَّهُ عَلَىَّ آيَاتٍ لَمْ يُرَ مِثْلُهُنَّ ‏(‏قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏)‏ إِلَى آخِرِ السُّورَةِ وَ ‏(‏قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏)‏ إِلَى آخِرِ السُّورَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2902}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Uqbah bin 'Amir Al-Juhani:that the Prophet (ﷺ) said: "Some Ayat have been revealed to me the likes of which have not been seen: Qul A'udhu Birabbin-Nas until the end of the Surah and Qul A'udhu Birabbil-Falaq until the end of the Surah}}
\hadithdefcmd{tirmidhi}{2903}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عُلَىِّ بْنِ رَبَاحٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَقْرَأَ بِالْمُعَوِّذَتَيْنِ فِي دُبُرِ كُلِّ صَلاَةٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2903}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Uqbah bin 'Amir:"The Messenger of Allah (ﷺ) ordered me to recite Al-Mu'awwidhatain at the end of every Salat}}
\hadithdefcmd{tirmidhi}{2904}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، قَالَ حَدَّثَنَا شُعْبَةُ، وَهِشَامٌ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الَّذِي يَقْرَأُ الْقُرْآنَ وَهُوَ مَاهِرٌ بِهِ مَعَ السَّفَرَةِ الْكِرَامِ الْبَرَرَةِ وَالَّذِي يَقْرَؤُهُ قَالَ هِشَامٌ وَهُوَ شَدِيدٌ عَلَيْهِ قَالَ شُعْبَةُ وَهُوَ عَلَيْهِ شَاقٌّ فَلَهُ أَجْرَانِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2904}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:that the Messenger of Allah (ﷺ) said: "The one who recites the Qur'an and he is proficient with it, then he is with the noble and blessed Angels (As-Safaratil-Kiramil-Bararah), and the one who recites it" - Hisham said: "And it is hard for him" - Shu'bah said: "And it is difficult for him, - then he gets two rewards}}
\hadithdefcmd{tirmidhi}{2905}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا حَفْصُ بْنُ سُلَيْمَانَ، عَنْ كَثِيرِ بْنِ زَاذَانَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ الْقُرْآنَ وَاسْتَظْهَرَهُ فَأَحَلَّ حَلاَلَهُ وَحَرَّمَ حَرَامَهُ أَدْخَلَهُ اللَّهُ بِهِ الْجَنَّةَ وَشَفَّعَهُ فِي عَشَرَةٍ مِنْ أَهْلِ بَيْتِهِ كُلُّهُمْ وَجَبَتْ لَهُ النَّارُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادٌ صَحِيحٍ ‏.‏ وَحَفْصُ بْنُ سُلَيْمَانَ أَبُو عُمَرَ بَزَّازٌ كُوفِيٌّ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏\hadithno{2905}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali bin Abi Talib:that the Messenger of Allah (ﷺ) said: "Whoever recites the Qur'an and memorizes it, making lawful what it makes lawful, and unlawful what it makes unlawful, Allah will admit him to Paradise due to it, and grant him intercession for ten of his family members who were to be consigned to the Fire}}
\hadithdefcmd{tirmidhi}{2906}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، قَالَ سَمِعْتُ حَمْزَةَ الزَّيَّاتَ، عَنْ أَبِي الْمُخْتَارِ الطَّائِيِّ، عَنِ ابْنِ أَخِي الْحَارِثِ الأَعْوَرِ، عَنِ الْحَارِثِ، قَالَ مَرَرْتُ فِي الْمَسْجِدِ فَإِذَا النَّاسُ يَخُوضُونَ فِي الأَحَادِيثِ فَدَخَلْتُ عَلَى عَلِيٍّ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ أَلاَ تَرَى أَنَّ النَّاسَ قَدْ خَاضُوا فِي الأَحَادِيثِ ‏.‏ قَالَ أَوَقَدْ فَعَلُوهَا قُلْتُ نَعَمْ ‏.‏ قَالَ أَمَا إِنِّي قَدْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَلاَ إِنَّهَا سَتَكُونُ فِتْنَةٌ ‏"‏ ‏.‏ فَقُلْتُ مَا الْمَخْرَجُ مِنْهَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ كِتَابُ اللَّهِ فِيهِ نَبَأُ مَا كَانَ قَبْلَكُمْ وَخَبَرُ مَا بَعْدَكُمْ وَحُكْمُ مَا بَيْنَكُمْ هُوَ الْفَصْلُ لَيْسَ بِالْهَزْلِ مَنْ تَرَكَهُ مِنْ جَبَّارٍ قَصَمَهُ اللَّهُ وَمَنِ ابْتَغَى الْهُدَى فِي غَيْرِهِ أَضَلَّهُ اللَّهُ وَهُوَ حَبْلُ اللَّهِ الْمَتِينُ وَهُوَ الذِّكْرُ الْحَكِيمُ وَهُوَ الصِّرَاطُ الْمُسْتَقِيمُ هُوَ الَّذِي لاَ تَزِيغُ بِهِ الأَهْوَاءُ وَلاَ تَلْتَبِسُ بِهِ الأَلْسِنَةُ وَلاَ يَشْبَعُ مِنْهُ الْعُلَمَاءُ وَلاَ يَخْلَقُ عَلَى كَثْرَةِ الرَّدِّ وَلاَ تَنْقَضِي عَجَائِبُهُ هُوَ الَّذِي لَمْ تَنْتَهِ الْجِنُّ إِذْ سَمِعَتْهُ حَتَّى قَالُوا ‏(‏إِنَّا سَمِعْنَا قُرْآنًا عَجَبًا * يَهْدِي إِلَى الرُّشْدِ فَآمَنَّا بِهِ ‏)‏ مَنْ قَالَ بِهِ صَدَقَ وَمَنْ عَمِلَ بِهِ أُجِرَ وَمَنْ حَكَمَ بِهِ عَدَلَ وَمَنْ دَعَا إِلَيْهِ هُدِيَ إِلَى صِرَاطٍ مُسْتَقِيمٍ ‏"‏ ‏.‏ خُذْهَا إِلَيْكَ يَا أَعْوَرُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حَمْزَةَ الزًّيَّاتِ وَإِسْنَادُهُ مَجْهُولٌ ‏.‏ وَفِي حَدِيثِ الْحَارِثِ مَقَالٌ ‏.‏\hadithno{2906}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Harith Al-A'war:"I passed by the Masjid when the people were absorbed in story-telling. So I entered upon 'Ali and said: 'O Commander of the believers! Do you not see the people are becoming engrossed in story-telling?' He said: 'They have been consumed with it?' I said: "Yes.' He said: 'As for me, I heard the Messenger of Allah (ﷺ) saying: "Indeed there comes a Fitnah" So I said: "What is the way out from it O Messenger of Allah?" He said: "Allah's book. In it is news for what happened before you, and information about what comes after you, and judgement for what happens between you. It is the Criterion (between right and wrong) without jest. Whoever among the oppressive abandons it, Allah crushes him, and whoever seeks guidance from other than it, then Allah leaves him to stray. It is the firm rope of Allah, it is the wise remembrance, it is the straight path, and it is the one that the desires can not distort, nor can the tongues twist it, nor can the scholars ever have enough of it, and it shall not become dull from reciting it much, and the amazement of it does not diminish. It is the one that when the Jinns hear it, they did not hesitate to say about it: 'Verily, we have heard a wonderful Recitation (this Qur'an)! 'It guides to the Right Path, and we have believed therein.' Whoever speaks according to it then he has said the truth, and whoever acts according to it he is rewarded, and whoever judges by it he has judged justly, and whoever invites to it then he guides to the straight path." Take this O A'war}}
\hadithdefcmd{tirmidhi}{2907}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَلْقَمَةُ بْنُ مَرْثَدٍ، قَالَ سَمِعْتُ سَعْدَ بْنَ عُبَيْدَةَ، يُحَدِّثُ عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُكُمْ مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ فَذَاكَ الَّذِي أَقْعَدَنِي مَقْعَدِي هَذَا ‏.‏ وَعَلَّمَ الْقُرْآنَ فِي زَمَنِ عُثْمَانَ حَتَّى بَلَغَ الْحَجَّاجَ بْنَ يُوسُفَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2907}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Abu 'Abdur-Rahman:from 'Uthman bin 'Affan that the Messenger of Allah (ﷺ) said: "The best of you is he who learns the Qur'an and teaches it." Abu 'Abdur-Rahman said: "So that is why I sit at this seat of mine." And he taught the Qur'an during the time of 'Uthman until Al-Hajjaj bin Yusuf came. (Sahih)}}
\hadithdefcmd{tirmidhi}{2908}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُكُمْ - أَوْ أَفْضَلُكُمْ - مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ وَغَيْرُ وَاحِدٍ عَنْ سُفْيَانَ الثَّوْرِيِّ عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ عَنْ أَبِي عَبْدِ الرَّحْمَنِ عَنْ عُثْمَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَسُفْيَانُ لاَ يَذْكُرُ فِيهِ عَنْ سَعْدِ بْنِ عُبَيْدَةَ ‏.‏ وَقَدْ رَوَى يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، هَذَا الْحَدِيثَ عَنْ سُفْيَانَ، وَشُعْبَةَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عُثْمَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم. حَدَّثَنَا بِذَلِكَ، مُحَمَّدُ بْنُ بَشَّارٍ قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ عَنْ سُفْيَانَ وَشُعْبَةَ ‏.‏ قَالَ مُحَمَّدُ بْنُ بَشَّارٍ وَهَكَذَا ذَكَرَهُ يَحْيَى بْنُ سَعِيدٍ عَنْ سُفْيَانَ، وَشُعْبَةَ، غَيْرَ مَرَّةٍ عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عُثْمَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ مُحَمَّدُ بْنُ بَشَّارٍ وَأَصْحَابُ سُفْيَانَ لاَ يَذْكُرُونَ فِيهِ عَنْ سُفْيَانَ عَنْ سَعْدِ بْنِ عُبَيْدَةَ ‏.‏ قَالَ مُحَمَّدُ بْنُ بَشَّارٍ وَهُوَ أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ زَادَ شُعْبَةُ فِي إِسْنَادِ هَذَا الْحَدِيثِ سَعْدَ بْنَ عُبَيْدَةَ وَكَأَنَّ حَدِيثَ سُفْيَانَ أَشْبَهُ ‏.‏ قَالَ عَلِيُّ بْنُ عَبْدِ اللَّهِ قَالَ يَحْيَى بْنُ سَعِيدٍ مَا أَحَدٌ يَعْدِلُ عِنْدِي شُعْبَةَ وَإِذَا خَالَفَهُ سُفْيَانُ أَخَذْتُ بِقَوْلِ سُفْيَانَ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ أَبَا عَمَّارٍ يَذْكُرُ عَنْ وَكِيعٍ قَالَ قَالَ شُعْبَةُ سُفْيَانُ أَحْفَظُ مِنِّي وَمَا حَدَّثَنِي سُفْيَانُ عَنْ أَحَدٍ بِشَيْءٍ فَسَأَلْتُهُ إِلاَّ وَجَدْتُهُ كَمَا حَدَّثَنِي ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَسَعْدٍ ‏.‏\hadithno{2908}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Uthman [bin 'Affan]:that the Messenger of Allah (ﷺ) said: "The best of you - or the most virtuous of you - is he who learns the Qur'an and teaches it}}
\hadithdefcmd{tirmidhi}{2909}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ سَعْدٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُكُمْ مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏ ‏.‏ وَهَذَا حَدِيثٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ ‏.‏\hadithno{2909}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ali bin Abi Talib:that the Messenger of Allah (ﷺ) said: "The best of you is he who learns the Qur'an and teaches it}}
\hadithdefcmd{tirmidhi}{2910}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، قَالَ حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، عَنْ أَيُّوبَ بْنِ مُوسَى، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ كَعْبٍ الْقُرَظِيَّ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ حَرْفًا مِنْ كِتَابِ اللَّهِ فَلَهُ بِهِ حَسَنَةٌ وَالْحَسَنَةُ بِعَشْرِ أَمْثَالِهَا لاَ أَقُولُ الم حَرْفٌ وَلَكِنْ أَلِفٌ حَرْفٌ وَلاَمٌ حَرْفٌ وَمِيمٌ حَرْفٌ ‏"‏ ‏.‏ وَيُرْوَى هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنِ ابْنِ مَسْعُودٍ وَرَوَاهُ أَبُو الأَحْوَصِ عَنِ ابْنِ مَسْعُودٍ رَفَعَهُ بَعْضُهُمْ وَوَقَفَهُ بَعْضُهُمْ عَنِ ابْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ سَمِعْتُ قُتَيْبَةَ بْنَ سَعِيدٍ يَقُولُ بَلَغَنِي أَنَّ مُحَمَّدَ بْنَ كَعْبٍ الْقُرَظِيَّ وُلِدَ فِي حَيَاةِ النَّبِيِّ صلى الله عليه وسلم وَمُحَمَّدُ بْنُ كَعْبٍ يُكْنَى أَبَا حَمْزَةَ ‏\hadithno{2910}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Muhammad bin Ka'b Al-Qurazi:"I heard 'Abdullah bin Mas'ud saying: 'The Messenger of Allah (ﷺ) said: "[Whoever recites a letter] from Allah's Book, then he receives the reward from it, and the reward of ten the like of it. I do not say that Alif Lam Mim is a letter, but Alif is a letter, Lam is a letter and Mim is a letter}}
\hadithdefcmd{tirmidhi}{2911}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا أَبُو النَّضْرِ، قَالَ حَدَّثَنَا بَكْرُ بْنُ خُنَيْسٍ، عَنْ لَيْثِ بْنِ أَبِي سُلَيْمٍ، عَنْ زَيْدِ بْنِ أَرْطَاةَ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا أَذِنَ اللَّهُ لِعَبْدٍ فِي شَيْءٍ أَفْضَلَ مِنْ رَكْعَتَيْنِ يُصَلِّيهِمَا وَإِنَّ الْبِرَّ لَيُذَرُّ عَلَى رَأْسِ الْعَبْدِ مَا دَامَ فِي صَلاَتِهِ وَمَا تَقَرَّبَ الْعِبَادُ إِلَى اللَّهِ بِمِثْلِ مَا خَرَجَ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو النَّضْرِ يَعْنِي الْقُرْآنَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَبَكْرُ بْنُ خُنَيْسٍ قَدْ تَكَلَّمَ فِيهِ ابْنُ الْمُبَارَكِ وَتَرَكَهُ فِي آخِرِ أَمْرِهِ ‏. وَقَدْ رُوِيَ هَذَا الْحَدِيثُ، عَنْ زَيْدِ بْنِ أَرْطَاةَ عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ ‏\hadithno{2911}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zaid bin Artah:narrated from Abu Umamah, that he Prophet (ﷺ) said: "Allah does not listen to anything more virtuous from the worshiper than the two Rak'ah of Salat he performs. And the righteousness spreads over the head of a worshiper as long as he remains in his Salat. And the worshipers shall not draw nearer to Allah, Mighty and Sublime is He, with similar to what came from Him}}
\hadithdefcmd{tirmidhi}{2912}{حَدَّثَنَا بِذَلِكَ إِسْحَاقُ بْنُ مَنْصُورٍ قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنْ زَيْدِ بْنِ أَرْطَاةَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ لَنْ تَرْجِعُوا إِلَى اللَّهِ بِأَفْضَلَ مِمَّا خَرَجَ مِنْهُ ‏"‏ ‏.‏ يَعْنِي الْقُرْآنَ ‏.‏\hadithno{2912}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jubair bin Nufair:that the Prophet (ﷺ) said: "You shall not return to Allah with what is more virtuous than what came from Him." Meaning the Qur'an}}
\hadithdefcmd{tirmidhi}{2913}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ قَابُوسِ بْنِ أَبِي ظَبْيَانَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الَّذِي لَيْسَ فِي جَوْفِهِ شَيْءٌ مِنَ الْقُرْآنِ كَالْبَيْتِ الْخَرِبِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2913}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said: "Indeed, the one who does not have the Qur'an inside him (his heart), is like the ruined house}}
\hadithdefcmd{tirmidhi}{2914}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ وَأَبُو نُعَيْمٍ، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُقَالُ يَعْنِي لِصَاحِبِ الْقُرْآنِ اقْرَأْ وَارْتَقِ وَرَتِّلْ كَمَا كُنْتَ تُرَتِّلُ فِي الدُّنْيَا فَإِنَّ مَنْزِلَتَكَ عِنْدَ آخِرِ آيَةٍ تَقْرَأُ بِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا بُنْدَارٌ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ عَاصِمٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2914}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Prophet (ﷺ) said: "It shall be said - meaning to the one who memorized the Qur'an - 'Recite, and rise up, recite (melodiously) as you would recite in the world. For indeed your rank shall be at the last Ayah you recited}}
\hadithdefcmd{tirmidhi}{2915}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَجِيءُ الْقُرْآنُ يَوْمَ الْقِيَامَةِ فَيَقُولُ يَا رَبِّ حَلِّهِ فَيُلْبَسَ تَاجَ الْكَرَامَةِ ثُمَّ يَقُولُ يَا رَبِّ زِدْهُ فَيُلْبَسَ حُلَّةَ الْكَرَامَةِ ثُمَّ يَقُولُ يَا رَبِّ ارْضَ عَنْهُ فَيَرْضَى عَنْهُ فَيُقَالُ لَهُ اقْرَأْ وَارْقَ وَيُزَادُ بِكُلِّ آيَةٍ حَسَنَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ عِنْدَنَا مِنْ حَدِيثِ عَبْدِ الصَّمَدِ عَنْ شُعْبَةَ ‏.‏\hadithno{2915}\hadithgrade{Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) said: "The one who memorized the Qur'an shall come on the Day of Judgement and (the reward for reciting the Qur'an) says: 'O Lord! Decorate him." So he is donned with a crown of nobility. Then it says: "O Lord! Give him more!' So he is donned with a suit of nobility. Then it says: "O Lord! Be pleased with him.' So He is pleased with him and says: "Recite and rise up, and be increased in reward with every Ayah}}
\hadithdefcmd{tirmidhi}{2916}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ الْحَكَمِ الْوَرَّاقُ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْمَجِيدِ بْنُ عَبْدِ الْعَزِيزِ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عُرِضَتْ عَلَىَّ أُجُورُ أُمَّتِي حَتَّى الْقَذَاةِ يُخْرِجُهَا الرَّجُلُ مِنَ الْمَسْجِدِ وَعُرِضَتْ عَلَىَّ ذُنُوبُ أَمَّتِي فَلَمْ أَرَ ذَنْبًا أَعْظَمَ مِنْ سُورَةٍ مِنَ الْقُرْآنِ أَوْ آيَةٍ أُوتِيهَا رَجُلٌ ثُمَّ نَسِيَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ وَذَاكَرْتُ بِهِ مُحَمَّدَ بْنَ إِسْمَاعِيلَ فَلَمْ يَعْرِفْهُ وَاسْتَغْرَبَهُ ‏.‏ قَالَ مُحَمَّدٌ وَلاَ أَعْرِفُ لِلْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ سَمَاعًا مِنْ أَحَدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ قَوْلَهُ حَدَّثَنِي مَنْ شَهِدَ خُطْبَةَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ وَسَمِعْتُ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ يَقُولُ لاَ نَعْرِفُ لِلْمُطَّلِبِ سَمَاعًا مِنْ أَحَدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ عَبْدُ اللَّهِ وَأَنْكَرَ عَلِيُّ بْنُ الْمَدِينِيِّ أَنْ يَكُونَ الْمُطَّلِبُ سَمِعَ مِنْ أَنَسٍ ‏.‏\hadithno{2916}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Muttalib bin 'Abullah bin Hantab:from Anas bin Malik that the Messenger of Allah (ﷺ) said: "The rewards for my Ummah were displayed before me, even (the reward for) the dust that a man comes out of the Masjid with. The sins of my Ummah were displayed before me, and I have not seen a sin worse than a Surah or Ayah of the Qur'an which a man learned and then forgot}}
\hadithdefcmd{tirmidhi}{2917}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّهُ مَرَّ عَلَى قَارِىءٍ يَقْرَأُ ثُمَّ سَأَلَ فَاسْتَرْجَعَ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَرَأَ الْقُرْآنَ فَلْيَسْأَلِ اللَّهَ بِهِ فَإِنَّهُ سَيَجِيءُ أَقْوَامٌ يَقْرَءُونَ الْقُرْآنَ يَسْأَلُونَ بِهِ النَّاسَ ‏"‏ ‏.‏ وَقَالَ مَحْمُودٌ هَذَا خَيْثَمَةُ الْبَصْرِيُّ الَّذِي رَوَى عَنْهُ جَابِرٌ الْجُعْفِيُّ وَلَيْسَ هُوَ خَيْثَمَةَ بْنَ عَبْدِ الرَّحْمَنِ وَخَيْثَمَةُ هَذَا شَيْخٌ بَصْرِيٌّ يُكْنَى أَبَا نَصْرٍ قَدْ رَوَى عَنْ أَنَسِ بْنِ مَالِكٍ أَحَادِيثَ وَقَدْ رَوَى جَابِرٌ الْجُعْفِيُّ عَنْ خَيْثَمَةَ هَذَا أَيْضًا أَحَادِيثَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ لَيْسَ إِسْنَادُهُ بِذَاكَ ‏.‏\hadithno{2917}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Hasan:that 'Imran bin Husain passed by a reciter reciting then he began begging. So he ('Imran) said: 'Indeed we are from Allah and to Him shall we return.' Then he said: 'I heard the Messenger of Allah (ﷺ) saying: 'Whoever recites the Qur'an, then let him ask Allah by it. For indeed there will come a people, who will recite the Qur'an, asking from the people because of it}}
\hadithdefcmd{tirmidhi}{2918}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ الْوَاسِطِيُّ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا أَبُو فَرْوَةَ، يَزِيدُ بْنُ سِنَانٍ عَنْ أَبِي الْمُبَارَكِ، عَنْ صُهَيْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا آمَنَ بِالْقُرْآنِ مَنِ اسْتَحَلَّ مَحَارِمَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِالْقَوِيِّ وَقَدْ خُولِفَ وَكِيعٌ فِي رِوَايَتِهِ ‏.‏ وَقَالَ مُحَمَّدٌ أَبُو فَرْوَةَ يَزِيدُ بْنُ سِنَانٍ الرُّهَاوِيُّ لَيْسَ بِحَدِيثِهِ بَأْسٌ إِلاَّ رِوَايَةَ ابْنِهِ مُحَمَّدٍ عَنْهُ فَإِنَّهُ يَرْوِي عَنْهُ مَنَاكِيرَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى مُحَمَّدُ بْنُ يَزِيدَ بْنِ سِنَانٍ عَنْ أَبِيهِ هَذَا الْحَدِيثَ فَزَادَ فِي هَذَا الإِسْنَادِ عَنْ مُجَاهِدٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ صُهَيْبٍ وَلاَ يُتَابَعُ مُحَمَّدُ بْنُ يَزِيدَ عَلَى رِوَايَتِهِ وَهُوَ ضَعِيفٌ وَأَبُو الْمُبَارَكِ رَجُلٌ مَجْهُولٌ ‏.‏\hadithno{2918}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Suhaib:that the Messenger of Allah (ﷺ) said: "He does not believe in the Qur'an who makes lawful what it prohibits}}
\hadithdefcmd{tirmidhi}{2919}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ كَثِيرِ بْنِ مُرَّةَ الْحَضْرَمِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْجَاهِرُ بِالْقُرْآنِ كَالْجَاهِرِ بِالصَّدَقَةِ وَالْمُسِرُّ بِالْقُرْآنِ كَالْمُسِرِّ بِالصَّدَقَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ أَنَّ الَّذِي يُسِرُّ بِقِرَاءَةِ الْقُرْآنِ أَفْضَلُ مِنَ الَّذِي يَجْهَرُ بِقِرَاءَةِ الْقُرْآنِ لأَنَّ صَدَقَةَ السِّرِّ أَفْضَلُ عِنْدَ أَهْلِ الْعِلْمِ مِنْ صَدَقَةِ الْعَلاَنِيَةِ وَإِنَّمَا مَعْنَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لِكَىْ يَأْمَنَ الرَّجُلُ مِنَ الْعُجُبِ لأَنَّ الَّذِي يُسِرُّ الْعَمَلَ لاَ يُخَافُ عَلَيْهِ الْعُجْبُ مَا يُخَافُ عَلَيْهِ مِنْ عَلاَنِيَتِهِ ‏.‏\hadithno{2919}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Uqbah bin 'Amir:that the Messenger of Allah (ﷺ) said: "The one who recites the Qur'an aloud is like the one who gives charity publicly, and the one who recites the Qur'an quietly is like the one who gives charity secretly}}
\hadithdefcmd{tirmidhi}{2920}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي لُبَابَةَ، قَالَ قَالَتْ عَائِشَةُ كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يَنَامُ حَتَّى يَقْرَأَ بَنِي إِسْرَائِيلَ وَالزُّمَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو لُبَابَةَ شَيْخٌ بَصْرِيٌّ قَدْ رَوَى عَنْهُ حَمَّادُ بْنُ زَيْدٍ غَيْرَ حَدِيثٍ وَيُقَالُ اسْمُهُ مَرْوَانُ ‏.‏ أَخْبَرَنِي بِذَلِكَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ فِي كِتَابِ التَّارِيخِ ‏.‏\hadithno{2920}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah:"The Prophet (ﷺ) would not sleep until he recited Surat Bani Isra'il and Az-Zumar}}
\hadithdefcmd{tirmidhi}{2921}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بِلاَلٍ، عَنْ عِرْبَاضِ بْنِ سَارِيَةَ، أَنَّهُ حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ الْمُسَبِّحَاتِ قَبْلَ أَنْ يَرْقُدَ وَيَقُولُ ‏ "‏ إِنَّ فِيهِنَّ آيَةً خَيْرٌ مِنْ أَلْفِ آيَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2921}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Irbad bin Sariyah:that the Prophet (ﷺ) would recite the Musabbihat (Chapters 17, 57, 59, 61, 62, 64 \& 87) before sleep and say "Indeed there is an Ayah in them that is better than one thousand Ayat}}
\hadithdefcmd{tirmidhi}{2922}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ طَهْمَانَ أَبُو الْعَلاَءِ الْخَفَّافُ، قَالَ حَدَّثَنِي نَافِعُ بْنُ أَبِي نَافِعٍ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ ثَلاَثَ مَرَّاتٍ أَعُوذُ بِاللَّهِ السَّمِيعِ الْعَلِيمِ مِنَ الشَّيْطَانِ الرَّجِيمِ وَقَرَأَ ثَلاَثَ آيَاتٍ مِنْ آخِرِ سُورَةِ الْحَشْرِ وَكَّلَ اللَّهُ بِهِ سَبْعِينَ أَلْفَ مَلَكٍ يُصَلُّونَ عَلَيْهِ حَتَّى يُمْسِيَ وَإِنْ مَاتَ فِي ذَلِكَ الْيَوْمِ مَاتَ شَهِيدًا وَمَنْ قَالَهَا حِينَ يُمْسِي كَانَ بِتِلْكَ الْمَنْزِلَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2922}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ma'qil bin Yasar:that the Prophet (ﷺ) said: "Whoever says three times when he gets up in the morning: 'A'udhu Billahis-Sami Al-'Alim Min Ash-Shaitanir-Rajim' and he recites three Ayat from the end of Surah Al-Hashr - Allah appoints seventy-thousand angels who say Salat upon him until the evening. If he dies on that day, he dies a martyr, and whoever reaches the evening, he holds the same status}}
\hadithdefcmd{tirmidhi}{2923}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ يَعْلَى بْنِ مَمْلَكٍ، أَنَّهُ سَأَلَ أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم عَنْ قِرَاءَةِ النَّبِيِّ صلى الله عليه وسلم وَصَلاَتِهِ فَقَالَتْ مَا لَكُمْ وَصَلاَتَهُ كَانَ يُصَلِّي ثُمَّ يَنَامُ قَدْرَ مَا صَلَّى ثُمَّ يُصَلِّي قَدْرَ مَا نَامَ ثُمَّ يَنَامُ قَدْرَ مَا صَلَّى حَتَّى يُصْبِحَ ثُمَّ نَعَتَتْ قِرَاءَتَهُ فَإِذَا هِيَ تَنْعَتُ قِرَاءَةً مُفَسَّرَةً حَرْفًا حَرْفًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ لَيْثِ بْنِ سَعْدٍ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنْ يَعْلَى بْنِ مَمْلَكٍ عَنْ أُمِّ سَلَمَةَ ‏.‏ وَقَدْ رَوَى ابْنُ جُرَيْجٍ هَذَا الْحَدِيثَ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنْ أُمِّ سَلَمَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُقَطِّعُ قِرَاءَتَهُ ‏.‏ وَحَدِيثُ لَيْثِ أَصَحُّ ‏.‏\hadithno{2923}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ya'la bin Mamlak:that he asked Umm Salamah, the wife of the Prophet (ﷺ), about the recitation of the Prophet (ﷺ) and his Salat. She said: "What can you do compared to his Salat? He would pray and then sleep as long as he had prayed. Then he would pray as long as he had slept. Then he slept as long as he had prayed until the morning.' Then she described his recitation. So she described his recitation as word by word}}
\hadithdefcmd{tirmidhi}{2924}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، هُوَ رَجُلٌ بَصْرِيٌّ قَالَ سَأَلْتُ عَائِشَةَ عَنْ وِتْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ كَانَ يُوتِرُ مِنْ أَوَّلِ اللَّيْلِ أَوْ مِنْ آخِرِهِ فَقَالَتْ كُلُّ ذَلِكَ قَدْ كَانَ يَصْنَعُ رُبَّمَا أَوْتَرَ مِنْ أَوَّلِ اللَّيْلِ وَرُبَّمَا أَوْتَرَ مِنْ آخِرِهِ ‏.‏ فَقُلْتُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً فَقُلْتُ كَيْفَ كَانَتْ قِرَاءَتُهُ أَكَانَ يُسِرُّ بِالْقِرَاءَةِ أَمْ يَجْهَرُ قَالَتْ كُلُّ ذَلِكَ كَانَ يَفْعَلُ قَدْ كَانَ رُبَّمَا أَسَرَّ وَرُبَّمَا جَهَرَ قَالَ فَقُلْتُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً قَالَ قُلْتُ فَكَيْفَ كَانَ يَصْنَعُ فِي الْجَنَابَةِ أَكَانَ يَغْتَسِلُ قَبْلَ أَنْ يَنَامَ أَمْ يَنَامُ قَبْلَ أَنْ يَغْتَسِلَ قَالَتْ كُلُّ ذَلِكَ قَدْ كَانَ يَفْعَلُ فَرُبَّمَا اغْتَسَلَ فَنَامَ وَرُبَّمَا تَوَضَّأَ فَنَامَ قُلْتُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2924}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Abdullah bin Abi Qais [A man from Al-Basrah]:"I asked 'Aishah about the Witr of the Messenger of Allah (ﷺ), how would he perform Witr, was it during the first part of the night or the end of it? She said: 'All of that. Sometimes he would perform Witr during the first part of the night, and sometimes he would perform Witr during the end of it.' So I said: 'All praise is due to Allah who made the matter accommodating.' I said: 'How was his recitation, was he quiet with recitations or loud?' She said: 'He would do all of that. Sometimes he would recite quietly and sometimes aloud.' I said: 'All praise is due to Allah who made the matter accommodating. He said: 'I said: 'How would he deal with sexual impurity? Would he perform Ghusl prior to sleeping or would he sleep prior to Ghusl?' She said: 'He would do all of that. Sometimes he would perform Ghusl then sleep, and sometimes he would perform Wudu and then sleep.' I said: 'Allah praise is due to Allah who made the matter accommodating}}
\hadithdefcmd{tirmidhi}{2925}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا إِسْرَائِيلُ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ الْمُغِيرَةِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعْرِضُ نَفْسَهُ بِالْمَوْقِفِ فَقَالَ ‏ "‏ أَلاَ رَجُلٌ يَحْمِلُنِي إِلَى قَوْمِهِ فَإِنَّ قُرَيْشًا قَدْ مَنَعُونِي أَنْ أُبَلِّغَ كَلاَمَ رَبِّي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{2925}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir bin 'Abdullah:"During the Mawqif (hajj season), the Prophet (ﷺ) would present himself and say: 'Which man will bring me to his people? For indeed the Quraish have prevented me from conveying the Speech of my Lord}}
\hadithdefcmd{tirmidhi}{2926}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا شِهَابُ بْنُ عَبَّادٍ الْعَبْدِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ الْحَسَنِ بْنِ أَبِي يَزِيدَ الْهَمْدَانِيُّ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَقُولُ الرَّبُّ عَزَّ وَجَلَّ مَنْ شَغَلَهُ الْقُرْآنُ عَنْ ذِكْرِي وَ مَسْأَلَتِي أَعْطَيْتُهُ أَفْضَلَ مَا أُعْطِي السَّائِلِينَ وَفَضْلُ كَلاَمِ اللَّهِ عَلَى سَائِرِ الْكَلاَمِ كَفَضْلِ اللَّهِ عَلَى خَلْقِهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2926}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Atiyyah:from Abu Sa'eed, that the Messenger of Allah (ﷺ) said: "The Lord, Blessed and Most High is He, has said: 'Whoever is too busy with the Qur'an for remembering Me and asking Me, then I shall give him more than what I give to those who ask.' And the virtue of Allah's Speech over the speech of others is like the virtue of Allah over His creation}}
